# Package

Here is a list of available actions for Data Package

- `check_package` -- check the descriptor against JSON Schema(s)
- `convert_package` -- convert the descriptor from one notation to another

## Reference

::: dplib.actions.package.check.check_package
::: dplib.actions.package.convert.convert_package
